%
% Sigma.cls 
% by Vladimir Batagelj, designed by Metka "Zerovnik
%
% based on SKRIPTA.STY  1989/09/13 - 1995/01/07 
%
% ver 0.1  1997/12/14

% --- Identification ----(gms 468)-------------------------- 
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{Sigma}[1997/12/14 v0.1 Sigma document class]
% --- Initial code   ---------------------------------------
\RequirePackage{latexsym}
\RequirePackage{fancyheadings}
\RequirePackage{csz}
% --- Declaration of options -------------------------------
\newif\if@draft \@draftfalse
\DeclareOption{draft}{\setlength\overfullrule{5pt}\@drafttrue}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
% --- Execution of options ---------------------------------
\ExecuteOptions{A4paper,10pt,twoside,onecolumn,final,fleqn}
\ProcessOptions
% --- Package loading --------------------------------------
\LoadClass{book}
% === Main code ============================================
\typeout{Document Style Option 'Skripta' ver 0.6. / 7-Jan-95 / V.B.}

% -------- Kotniki ---------------------------

\newcommand{\luc}{%
 \raisebox{16mm}[6mm]{%
  \makebox[0pt][r]{%
   \rule{10mm}{0.15pt}%
   \hspace{2mm}%
%   \makebox[0pt]{\framebox[140mm][l]{\rule[-200mm]{0pt}{200mm}}}%
   \raisebox{2mm}[0mm]{\rule{0.15pt}{10mm}}%
   \hspace{\ifodd\value{page}16\else 12\fi mm}%
  }%
 }%
}
\newcommand{\ruc}{%
 \raisebox{16mm}[6mm]{%
  \makebox[0pt][l]{%
   \hspace{\ifodd\value{page}12\else 16\fi mm}%
   \raisebox{2mm}[0mm]{\rule{0.15pt}{10mm}}%
   \hspace{2mm}%
   \rule{10mm}{0.15pt}%
  }%
 }%
}
\newcommand{\llc}{%
 \raisebox{-8mm}[6mm]{%
  \makebox[0pt][r]{%
   \rule{10mm}{0.15pt}%
   \hspace{2mm}%
   \raisebox{-12mm}[0mm]{\rule{0.15pt}{10mm}}%
   \hspace{\ifodd\value{page}16\else 12\fi mm}%
  }%
 }%
}
\newcommand{\rlc}{%
 \raisebox{-8mm}[6mm]{%
  \makebox[0pt][l]{%
   \hspace{\ifodd\value{page}12\else 16\fi mm}%
   \raisebox{-12mm}[0mm]{\rule{0.1pt}{10mm}}%
   \hspace{2mm}%
   \rule{10mm}{0.1pt}%
  }%
 }%
}

% ------- Prve strani -----------

\newcommand{\autfont}{\fontsize{15}{17pt}\normalfont\rmfamily}
\newcommand{\titfont}{\fontsize{18}{21pt}\normalfont\rmfamily\bfseries}
\newcommand{\chcfont}{\fontsize{36}{39pt}\normalfont\rmfamily\bfseries}

\def\footer#1{\gdef\@footer{#1}}
\def\@footer{\copyright\number\year\ \@author}

\newcommand{\makesigma}[1]{%
 \renewcommand{\thepage}{\hspace*{2mm}}
 \setcounter{page}{1}
 \thispagestyle{empty}
 \begin{flushright}
  \strut\vfill
  \textbf{KNJI"ZNICA SIGMA -- #1}
 \end{flushright}
 \newpage
 \begin{flushright}
%  \thispagestyle{fancyplain}
   \strut
    {\autfont \@author\par}%
    {\titfont \@title \par}%
    \vfill\null
    {\normalsize Dru"stvo matematikov, fizikov in astronomov Slovenije\\
             \@date \par}%       
 \end{flushright}
 \newpage
 \strut\vfill
 Izdajo KNJI"ZNICE SIGMA sofinancirata:\\
 \null\\
 Ministrstvo za znanost in tehnologijo\\
 Ministrstvo za "solstvo in "sport
 \renewcommand{\thepage}{\arabic{page}}
}

% *** page layout

\marginparsep 10pt \topmargin 24 true mm
\headheight 12pt \headsep 25pt
\footskip 30pt
\textheight 161 true mm \textwidth 112 true mm

\if@twoside \oddsidemargin 16mm \evensidemargin 12mm \marginparwidth 30mm
 \else \oddsidemargin 16mm \evensidemargin 16mm \marginparwidth 30mm \fi

\setlength{\parskip}{0.5\baselineskip}
\setlength{\parindent}{0pt}
\setlength{\mathindent}{10mm}
\setlength{\topsep}{0.5\baselineskip}

% *** floats control

\setcounter{topnumber}{4}
\setcounter{totalnumber}{4}
\renewcommand{\topfraction}{0.8}
\renewcommand{\textfraction}{0.2}

% *** clock macro

\newcommand{\clock}{\count254=\time \divide\count254 by 60
 \count255=\count254 \multiply\count255 by -60
 \advance\count255 by \time
 \ifnum\count254<10 0\fi\number\count254\,:\,%
 \ifnum\count255<10 0\fi\number\count255}

% *** headers and footers (fancyheadings)

\pagestyle{fancyplain}
% \addtolength{\headwidth}{\marginparsep}
% \addtolength{\headwidth}{\marginparwidth}
\renewcommand{\chaptermark}[1]{\markboth{\thechapter. \uppercase{#1}}{\thechapter. \uppercase{#1}}} % remember chapter title
\renewcommand{\sectionmark}[1]{\markright{\thesection\ #1}}
                                                % section number and title
\lhead[\fancyplain{}{\luc\small\bf\thepage}]{\fancyplain{}{\luc\small\it\rightmark}}
\rhead[\fancyplain{}{\small\it\leftmark\ruc}]{\fancyplain{}{\small\bf\thepage\ruc}}
\cfoot{}
\lfoot{\fancyplain{}{\llc}}
\rfoot{\fancyplain{}{\rlc}}

% ---------- Index entries and draft ---------------

\newcommand{\si}[1]{#1\index{#1}}
\newcommand{\sis}[2]{#1\index{#2!#1}}
\newcommand{\sie}[1]{\index{#1}}
\newcommand{\sid}[1]{\emph{#1}\index{#1}}

%
% draft
%

\newcommand{\setdraft}{
 \plainfootrulewidth 0.4pt \footrulewidth 0.4pt
 \lfoot{\fancyplain{\small\@footer}{\llc\small\@footer}}%
 \rfoot{\fancyplain{\small\today / \clock}{\small\today / \clock\rlc}}%
 \renewcommand{\si}[1]{\fbox{##1}\index{##1}}%
 \renewcommand{\sis}[2]{\fbox{##1}\index{##2!##1}}%
 \renewcommand{\sie}[1]{\index{##1}\ifodd\value{page} \normalmarginpar
  \else \reversemarginpar \fi\marginpar{\footnotesize \texttt{idx:} ##1}}%
 \renewcommand{\sid}[1]{\fbox{\emph{##1}}\index{##1}}%
 \gdef\remark##1{\marginpar{{\footnotesize ##1}}}
}

% ----------  Footnoterule -------------

 \renewcommand{\footnoterule}{\vspace*{-3pt}%
  \rule{20mm}{0.4pt}\vspace*{2.6pt}}

% --- Chapter --------------------------

\renewcommand\thepart {\@Roman\c@part}
\renewcommand\thechapter {\@arabic\c@chapter}
\renewcommand\thesection {\thechapter.\@arabic\c@section.}
\renewcommand\thesubsection   {\thesection\@arabic\c@subsection.}
\renewcommand\thesubsubsection{\thesubsection\@arabic\c@subsubsection.}
\renewcommand\theparagraph    {\thesubsubsection\@arabic\c@paragraph.}
\renewcommand\thesubparagraph {\theparagraph\@arabic\c@subparagraph.}

\renewcommand\chapter{\clearpage
 \thispagestyle{plain}%
 \global\@topnum\z@
 \@afterindentfalse
 \secdef\@chapter\@schapter%
}

\def\@makechapterhead#1{%
  {\parindent \z@ \normalfont
    \raisebox{10mm}[0pt]{\rule{112mm}{0.4pt}}
    \ifodd\value{page} \begin{flushleft}
     \else \begin{flushright}\fi
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
        {\chcfont\thechapter}\\[5pt]
      \fi
    \fi
    \interlinepenalty\@M
    \titfont \uppercase\expandafter{#1}\par\null
    \ifodd\value{page} \end{flushleft}
     \else \end{flushright}\fi
    \hrule
    \vspace*{12mm}\par
  }}

\def\@makeschapterhead#1{%
  {\parindent \z@ \raggedright
    \addcontentsline{toc}{chapter}{\protect\numberline{~}\expandafter{#1}}%
    \normalfont
    \raisebox{10mm}[0pt]{\rule{112mm}{0.4pt}}
    \interlinepenalty\@M
    \ifodd\value{page} \begin{flushleft}
     \else \begin{flushright}\fi
    \titfont \uppercase\expandafter{#1}\par\null
    \ifodd\value{page} \end{flushleft}
     \else \end{flushright}\fi
    \hrule
    \vspace*{12mm}\par
  }}

\renewcommand\tableofcontents{%
    \chapter*{\contentsname}
    \@mkboth{%
           \MakeUppercase\contentsname}{\MakeUppercase\contentsname}%
    \@starttoc{toc}%
}

\renewenvironment{thebibliography}[1]{%
      \chapter*{\bibname}
        \@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}%
      \small
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}


\renewcommand{\l@chapter}{\@dottedtochline{1}{0mm}{10mm}}

\def\@dottedtochline#1#2#3#4#5{%
  \ifnum #1>\c@tocdepth \else
    {\setlength{\parskip}{6pt}%
     \leftskip #2\relax \rightskip \@tocrmarg \parfillskip -\rightskip
     \parindent #2\relax\@afterindenttrue
     \interlinepenalty\@M
     \leavevmode\bfseries
     \@tempdima #3\relax
     \advance\leftskip \@tempdima \null\nobreak\hskip -\leftskip
     {#4}\nobreak \normalfont 
     \leaders\hbox{$\m@th
        \mkern \@dotsep mu\hbox{.}\mkern \@dotsep
        mu$}\hfill
     \nobreak
     \hb@xt@\@pnumwidth{\hfil\normalcolor \bfseries #5}%
     \par}%
  \fi}

\def\@dottedtocline#1#2#3#4#5{%
  \ifnum #1>\c@tocdepth \else
    {\setlength{\parskip}{1pt}%
     \leftskip #2\relax \rightskip \@tocrmarg \parfillskip -\rightskip
     \parindent #2\relax\@afterindenttrue
     \interlinepenalty\@M
     \leavevmode
     \@tempdima #3\relax
     \advance\leftskip \@tempdima \null\nobreak\hskip -\leftskip
     {#4}\nobreak
     \leaders\hbox{$\m@th
        \mkern \@dotsep mu\hbox{.}\mkern \@dotsep
        mu$}\hfill
     \nobreak
     \hb@xt@\@pnumwidth{\hfil\normalfont \normalcolor #5}%
     \par}%
  \fi}

\renewcommand{\l@section}{\@dottedtocline{1}{0mm}{10mm}}
\renewcommand{\l@subsection}{\@dottedtocline{2}{0mm}{10mm}}
\renewcommand{\l@subsubsection}{\@dottedtocline{3}{0mm}{10mm}}
\renewcommand{\l@paragraph}{\@dottedtocline{4}{0mm}{10mm}}
\renewcommand{\l@subparagraph}{\@dottedtocline{5}{0mm}{10mm}}

\if@draft \setdraft 
\else
 \newcommand{\remark}[1]{}
\fi

% SLOVEN2E.STY

\def\abstractname{Povzetek}
\def\appendixname{Dodatek}
\def\bibname{Literatura}
\def\ccname{cc}
\def\chaptername{Poglavje}
\def\contentsname{Vsebina}
\def\enclname{Priloge}
\def\figurename{Slika\ }
\def\headpagename{Stran}
\def\headtoname{Komu}
\def\indexname{Stvarno kazalo}
\def\listoffigures{Slike}
\def\listtablename{Tabele}
\def\partname{Del}
\def\prefacename{Predgovor}
\def\seename{glej}
\def\alsoseename{glej tudi}
\def\refname{Viri}
\def\tablename{Tabela\ }

% tekoci datum

\def\today{\number\day. \ifcase\month\or
 januar\or februar\or marec\or april\or maj\or junij\or
 julij\or avgust\or september\or oktober\or november\or december\fi
 \space\number\year}

% slovenski narekovaji

\def\lqlq{\leavevmode\hbox{,\kern-.1em,}}
\def\rqrq{\leavevmode\hbox{`\kern-.1em`}}

% ------------
\newcommand{\res}{{\rm r}}
\newcommand{\7}{\'{c}}
\newcommand{\Q}{\circle*{3}}

\newcommand{\centigrade}{\char'027$\$C}   % \centigrade  Celsius degrees

\newcommand{\degrees}{^\circ}
\mathchardef\dash=45
\def\rr{\mathop{\bf r}\nolimits}

\newcommand{\no}[1]{\makebox[1ex]{#1}}

\newcommand{\deriv}[2]{\frac{{\rm d} #1}{{\rm d} #2}}
\newcommand{\dderiv}[2]{\frac{{\rm d}^2 #1}{{\rm d} #2^2}}
\newcommand{\pardf}[2]{\frac{\partial #1}{\partial #2}}
\newcommand{\pards}[2]{\frac{\partial^2 #1}{\partial #2^2}}
\newcommand{\pardxy}[3]{\frac{\partial^2 #1}{\partial #2 \partial #3}}

\newcommand{\lcm}{\rm lcm}

\newcommand{\crta}[1]{\overline{#1}}
% \newcommand{\con}{\mbox{\rm con\,}}
\newcommand{\mv}{\rule[-1.25ex]{0mm}{3.6ex}}
\newcommand{\rec}[1]{\frac{1}{#1}}
\newcommand{\lab}[1]{\mbox{#1}}

% \xor

\newbox\orbox
\mathchardef\orr=607    % "025F
\newcommand{\xor}{\setbox\orbox=\hbox{$\orr$}%
  \mathbin{\orr\llap{\kern.1\wd\orbox
    \vrule height.05ex width.8\wd\orbox depth.05ex
    \kern.1\wd\orbox}} }

%
%    o k o l j a
%

 \newcommand{\slikaEPS}[3]{%
   \begin{figure}
    \begin{center}
     \epsfig{figure=#1.eps,width=#2}
    \end{center}
    \caption{#3}
   \end{figure}
  }

 \newcommand{\slika}[4]{\begin{figure}
   \begin{center}
    \par\framebox{ \vbox to #3{\hbox to #2{\special{em:graph #1,#2}}
    \vfill\rm}}
   \end{center}
   \caption{#4}
  \end{figure}}

%
% Theorems
%

 \newtheorem{izrek}{IZREK}[chapter]
 \newtheorem{trditev}[izrek]{TRDITEV}
 \newtheorem{posledica}[izrek]{POSLEDICA}
 \renewcommand{\theizrek}{\thechapter.\arabic{izrek}. \ }
 \newcommand{\konec}{\hspace*{1mm}\hfill$\Box$\endgraf}
 \newenvironment{dokaz}{{\bf Dokaz:}\ }{\konec}

 \newenvironment{opomba}{\medbreak\par\noindent{\bf OPOMBA:}\ }{\konec}

 \newcounter{example}[chapter]
 \newenvironment{zgled}{\medbreak \par \refstepcounter{example}%
   \noindent{\bf PRIMER \thechapter.\theexample.} \ }%
   {\hspace*{1pt}\konec}

% program

 \newenvironment{program}{\renewcommand{\figurename}{Program }%
   \renewcommand{\baselinestretch}{0.75}%
   \begin{figure}}{\end{figure}\renewcommand{\figurename}{Slika }}

%
% system
%

 \catcode`\@=11
 \def\system#1{\vcenter{\openup1\jot\m@th
   \ialign{&\hfil$##$&$##$\hfil&\strut${}##{}$\crcr
   #1\crcr}}}
 \catcode`\@=12

%
% operations, relations
%

% \newcommand{\sqsubsetdot}{\mathrel{\sqsubset\llap{$\cdot$}}}
 \newcommand{\sqsubsetdot}{\mathrel{\sqsubset\kern-1.6ex\cdot}}

%
% functions
%

 \def\tg{\mathop{\rm tg}\nolimits}
 \def\ctg{\mathop{\rm ctg}\nolimits}
 \def\sh{\mathop{\rm sh}\nolimits}
 \def\ch{\mathop{\rm ch}\nolimits}
 \def\th{\mathop{\rm th}\nolimits}
 \def\cth{\mathop{\rm cth}\nolimits}
 \def\arc{\mathop{\rm arc}\nolimits}
 \def\Arc{\mathop{\rm Arc}\nolimits}

 \def\Grad{\mathop{\rm grad}\nolimits}
 \def\Div{\mathop{\rm div}\nolimits}
 \def\Rot{\mathop{\rm rot}\nolimits}

 \def\var{\mathop{\rm var}\nolimits}
 \def\cov{\mathop{\rm cov}\nolimits}
 \def\sign{\mathop{\rm sign}\nolimits}

 \def\Min{\mathop{\rm Min}}
 \def\Max{\mathop{\rm Max}}
 \def\argmin{\mathop{\rm argmin}}
 \def\argmax{\mathop{\rm argmax}}
 \def\card{\mathop{\rm card}\nolimits}
 \def\Cn{\mathop{\rm Cn}\nolimits}
 \def\cn{\mathop{\rm cn}\nolimits}
 \def\ord{\mathop{\rm ord}\nolimits}

 \newcommand{\upset}[1]{\uparrow\!(#1)}
 \newcommand{\downset}[1]{\downarrow\!(#1)}

% \mathchardef\hyphen="002D

 \newcommand{\Qed}{\strut\hfill$\Box$\endgraf}

%
% Sets
%
 \def\NN{\hbox{\sf I\kern-.13em\hbox{N}}}
 \def\RR{\hbox{\sf I\kern-.14em\hbox{R}}}
 \def\ZZ{{\hbox{\sf Z\kern-.43emZ}}}
 \def\CC{\hbox{\sf C\kern -.48emC}}
 \def\QQ{\hbox{\sf C\kern -.48emQ}}
 \def\Cc{\hbox{\sf C\kern -.47em {\raise .48ex \hbox{$\scriptscriptstyle |$}}
   \kern-.5em {\raise .48ex \hbox{$\scriptscriptstyle |$}} }}
 \def\Qq{\hbox{\sf Q\kern -.57em {\raise .48ex \hbox{$\scriptscriptstyle |$}}
   \kern-.55em {\raise .48ex \hbox{$\scriptscriptstyle |$}} }}
 \newcommand{\BB}{\hbox{\sf I\kern-.14em\hbox{B}}}

\newcommand{\Times}{\mathop{\mbox{\huge $\times$}}}

\newcommand{\Dom}{{\cal D}}
\newcommand{\Ran}{{\cal R}}
\newcommand{\id}{\mbox{\rm id}}
\newcommand{\Id}{\mbox{\rm I}}
\newcommand{\Total}{\mbox{\rm T}}

\newcommand{\Rel}{\mbox{\bf Rel}}
\newcommand{\Eqv}{\mbox{\bf Eqv}}
\newcommand{\Graph}{\mbox{\bf Gph}}
\newcommand{\degree}{\mbox{\rm deg}}
\newcommand{\val}{\mbox{\rm val}}
\newcommand{\outdeg}{\mbox{\rm outdeg}}
\newcommand{\indeg}{\mbox{\rm indeg}}
\newcommand{\ext}{\mbox{\rm ext}}
\newcommand{\ini}{\mbox{\rm ini}}
\newcommand{\ter}{\mbox{\rm ter}}
\newcommand{\twin}{\mbox{\rm twin}}
\newcommand{\Mat}[1]{\mbox{\bf #1}}


\endinput

%******************************************************************

